@@ -54,6 +54,37 @@ if ( !function_exists('dbg_error_log') ) {
 }
 
 
+if ( !function_exists('fatal') ) {
+  function fatal() {
+    global $c;
+    $args = func_get_args();
+    $argc = func_num_args();
+    if ( 2 <= $argc ) {
+      $format = array_shift($args);
+    }
+    else {
+      $format = "%s";
+    }
+    @error_log( $c->sysabbr.": FATAL: $component:". vsprintf( $format, $args ) );
+    
+    @error_log( "================= Stack Trace ===================" );
+	
+  	$trace = array_reverse(debug_backtrace());
+    array_pop($trace);
+    foreach( $trace AS $k => $v ) {
+ 	  @error_log( sprintf(" ===>  %s[%d] calls %s%s%s()",
+	               $v['file'],
+	               $v['line'],
+	               (isset($v['class'])?$v['class']:''),
+	               (isset($v['type'])?$v['type']:''),
+	               (isset($v['function'])?$v['function']:'')
+	      ));
+    }
+    echo "Fatal Error";
+    exit();
+  }
+}
+
 
 if ( !function_exists('apache_request_headers') ) {
   /**
@@ -525,19 +556,46 @@ function olson_from_tzstring( $tzstring ) {
   }
   switch( $tzstring ) {
     case 'New Zealand Standard Time': case 'New Zealand Daylight Time': return 'Pacific/Auckland'; break;
-    case 'Central Standard Time':     case 'Central Daylight Time':     return 'America/Chicago';  break;
-    case 'Eastern Standard Time':     case 'Eastern Daylight Time':     return 'America/New_York'; break;
-    case 'Pacific Standard Time':     case 'Pacific Daylight Time':     return 'America/Los_Angeles'; break;
+    case 'Central Standard Time':     case 'Central Daylight Time':     case 'US/Central':
+         return 'America/Chicago';
+         break;
+    case 'Eastern Standard Time':     case 'Eastern Daylight Time':     case 'US/Eastern':
+    case '(UTC-05:00) Eastern Time (US & Canada)':
+         return 'America/New_York';
+         break;
+    case 'Pacific Standard Time':     case 'Pacific Daylight Time':     case 'US/Pacific':
+         return 'America/Los_Angeles';
+         break;
+    case 'Mountain Standard Time':    case 'Mountain Daylight Time':    case 'US/Mountain':    case 'Mountain Time':
+         return 'America/Denver';
+         // The US 'Mountain Time' can in fact be America/(Denver|Boise|Phoenix|Shiprock) which
+         // all vary to some extent due to differing DST rules.
+         break;
   }
   return null;
 }
 
+if ( !function_exists("deprecated") ) {
+  function deprecated( $method ) {
+    global $c;
+    if ( isset($c->dbg['ALL']) || isset($c->dbg['deprecated']) ) {
+      $stack = debug_backtrace();
+      array_shift($stack);
+      if ( preg_match( '{/inc/iCalendar.php$}', $stack[0]['file'] ) && $stack[0]['line'] > __LINE__ ) return;
+      @error_log( sprintf( $c->sysabbr.':DEPRECATED: Call to deprecated method "%s"', $method));
+      foreach( $stack AS $k => $v ) {
+        @error_log( sprintf( $c->sysabbr.':  ==>  called from line %4d of %s', $v['line'], $v['file']));
+      }
+    }
+  }
+}
+
 
 /**
  * Return the AWL version
  */
 function awl_version() {
   global $c;
-$c->awl_library_version = 0.46;
+$c->awl_library_version = 0.47;
   return $c->awl_library_version;
 }
\ No newline at end of file
