@@ -10,7 +10,7 @@
 * @subpackage vComponent
 * @author Andrew McMillan <andrew@mcmillan.net.nz>
 * @copyright Morphoss Ltd <http://www.morphoss.com/>
-* @license   http://gnu.org/copyleft/gpl.html GNU GPL v2 or later
+* @license   http://gnu.org/copyleft/lgpl.html GNU LGPL v2 or later
 *
 */
 require_once('XMLElement.php');
@@ -87,8 +87,24 @@ class vProperty {
 
     $unescaped = preg_replace( '{\\\\[nN]}', "\n", $propstring);
 
-    // Split into two parts on : which is not preceded by a \
-    list( $start, $values) = preg_split( '{(?<!\\\\):}', $unescaped, 2);
+    // Split into two parts on : which is not preceded by a \, or within quotes like "str:ing".
+    $offset = 0;
+    do {
+      $splitpos = strpos($unescaped,':',$offset);
+      $start = substr($unescaped,0,$splitpos);
+      if ( substr($start,-1) == '\\' ) {
+        $offset = $splitpos + 1;
+        continue;
+      }
+      $quotecount = strlen(preg_replace('{[^"]}', '', $start ));
+      if ( ($quotecount % 2) != 0 ) {
+        $offset = $splitpos + 1;
+        continue;
+      }
+      break;
+    }
+    while( true );
+    $values = substr($unescaped,$splitpos+1);
     $this->content = preg_replace( "/\\\\([,;:\"\\\\])/", '$1', $values);
 
     // Split on ; which is not preceded by a \
@@ -100,6 +116,9 @@ class vProperty {
       $pos = strpos($v,'=');
       $name = strtoupper(substr( $v, 0, $pos));
       $value = substr( $v, $pos + 1);
+      if ( preg_match( '{^"(.*)"$}', $value, $matches) ) {
+        $value = $matches[1];
+      }
       $this->parameters[$name] = $value;
     }
 //    dbg_error_log('vComponent', " vProperty::ParseFrom found '%s' = '%s' with %d parameters", $this->name, substr($this->content,0,200), count($this->parameters) );
@@ -203,7 +222,7 @@ class vProperty {
   function RenderParameters() {
     $rendered = "";
     foreach( $this->parameters AS $k => $v ) {
-      $escaped = preg_replace( "/([;:\"])/", '\\\\$1', $v);
+      $escaped = preg_replace( "/([;:])/", '\\\\$1', $v);
       $rendered .= sprintf( ";%s=%s", $k, $escaped );
     }
     return $rendered;
@@ -235,7 +254,7 @@ class vProperty {
       default:
         $escaped = str_replace( '\\', '\\\\', $escaped);
         $escaped = preg_replace( '/\r?\n/', '\\n', $escaped);
-        $escaped = preg_replace( "/([,;\"])/", '\\\\$1', $escaped);
+        $escaped = preg_replace( "/([,;])/", '\\\\$1', $escaped);
     }
 
     $property = sprintf( "%s%s:", $this->name, $this->RenderParameters() );
@@ -569,6 +588,16 @@ class vComponent {
   }
 
 
+  /**
+  * Return the value of the first instance of a property of this name, or null
+  */
+  function GetPValue( $type ) {
+    $p = $this->GetProperty($type);
+    if ( isset($p) ) return $p->Value();
+    return null;
+  }
+
+  
   /**
   * Get all properties, or the properties matching a particular type, or matching an
   * array associating property names with true values: array( 'PROPERTY' => true, 'PROPERTY2' => true )
@@ -800,6 +829,7 @@ class vComponent {
     foreach( $this->components AS $v ) {   $rendered .= $v->Render();  }
     $rendered .= "END:$this->type\r\n";
 
+    $rendered = preg_replace('{(?<!\r)\n}', "\r\n", $rendered);
     if ( $unrestricted ) $this->rendered = $rendered;
 
     return $rendered;
